Move

Trait Move 

pub trait Move<'owner>: MoveRef<'owner> + MoveMut<'owner> { }
Trait for containers which hold different kinds of reference.

Combines MoveRef and MoveMut functionality together, allowing to move immutable and mutable references from the same container.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'owner, T> Move<'owner> for T
where T: ?Sized + MoveRef<'owner> + MoveMut<'owner>,

Technically, Move is a trait alias to MoveRef + MoveMut trait combination.